@@ -5,16 +5,16 @@
 # Joan Ntzougani, gravitalsun@hotmail.com
 
 package Dancer2::Plugin::WebService;
-our	$VERSION = '4.3.1';
+our	$VERSION = '4.3.2';
 use	strict;
 use	warnings;
 use Encode;
 use	Dancer2::Plugin;
 use	Storable;
-use	Data::Dumper;     $Data::Dumper::Sortkeys=0;     $Data::Dumper::Indent=2;     $Data::Dumper::Purity=1; $Data::Dumper::Terse=1; $Data::Dumper::Deepcopy=1; $Data::Dumper::Trailingcomma=0;
-use YAML::Syck;       $YAML::Syck::ImplicitTyping=1; $YAML::Syck::Headless=0;     $YAML::Syck::ImplicitUnicode=0;
-use	XML::Hash::XS;    $XML::Hash::XS::root='Data';   $XML::Hash::XS::canonical=0; $XML::Hash::XS::indent=2; $XML::Hash::XS::utf8=1; $XML::Hash::XS::encoding='utf8'; $XML::Hash::XS::xml_decl=0; $XML::Hash::XS::doc=0;
-use Cpanel::JSON::XS; my $JSON=Cpanel::JSON::XS->new;$JSON->canonical(0); $JSON->pretty(0); $JSON->indent(1); $JSON->space_before(1); $JSON->space_after(1); $JSON->max_size(0); $JSON->relaxed(0); $JSON->shrink(0); $JSON->allow_tags(1); $JSON->allow_nonref(0); $JSON->allow_unknown(0); $JSON->allow_blessed(1); $JSON->convert_blessed(1); $JSON->max_depth(1024); $JSON->utf8(0);
+use	XML::Hash::XS; $XML::Hash::XS::utf8=1;  $XML::Hash::XS::encoding='utf8'; $XML::Hash::XS::root='Data'; $XML::Hash::XS::canonical=0; $XML::Hash::XS::indent=2; $XML::Hash::XS::xml_decl=0; $XML::Hash::XS::doc=0;
+use	Data::Dumper;  $Data::Dumper::Terse=1;  $Data::Dumper::Trailingcomma=0;  $Data::Dumper::Deepcopy=1; $Data::Dumper::Indent=2; $Data::Dumper::Purity=1; $Data::Dumper::Sortkeys=0;
+use YAML::Syck;    $YAML::Syck::Headless=0; $YAML::Syck::ImplicitTyping=1;   $YAML::Syck::ImplicitUnicode=0;
+use Cpanel::JSON::XS; my $JSON=Cpanel::JSON::XS->new; $JSON->space_before(1);$JSON->canonical(0);  $JSON->allow_tags(1);  $JSON->allow_unknown(0); $JSON->pretty(0); $JSON->indent(1); $JSON->space_after(1); $JSON->max_size(0); $JSON->relaxed(0); $JSON->shrink(0); $JSON->allow_nonref(0); $JSON->allow_blessed(1); $JSON->convert_blessed(1); $JSON->max_depth(1024); $JSON->utf8(0);
 
 if ($^O=~/(?i)MSWin/) {warn "Operating system is not supported\n"; exit 1}
 
@@ -32,7 +32,7 @@ has auth_command    => (is=>'rw', lazy=>1, default=> '');
 has auth_config     => (is=>'rw', lazy=>1, default=> sub{ {} });
 has data            => (is=>'rw', lazy=>1, default=> sub{ {} });	# user posted data as hash
 has Session_timeout => (is=>'ro', lazy=>0, from_config=>'Session idle timeout',default=> sub{ 3600 }, isa => sub {unless ( $_[0]=~/^\d+$/ ) {warn "Session idle timeout \"$_[0]\" It is not a number\n"; exit 1}} );
-has rules           => (is=>'ro', lazy=>0, from_config=>'Allowed hosts',       default=> sub{ ['127.0.*', '192.168.*', '10.*', '172.16.*'] });
+has rules           => (is=>'ro', lazy=>0, from_config=>'Allowed hosts',       default=> sub{ ['127.0.*', '192.168.*', '172.16.*'] });
 has rules_compiled  => (is=>'ro', lazy=>0, default=> sub {my $array = [@{$_[0]->rules}]; for (@{$array}) { s/([^?*]+)/\Q$1\E/g; s|\?|.|g; s|\*+|.*?|g; $_ = qr/^$_$/i } $array});
 has dir_session     => (is=>'ro', lazy=>0, default=> sub {my $dir = exists $_[0]->config->{'Session directory'} ? $_[0]->config->{'Session directory'}."/$_[0]->{app}->{name}" : "$_[0]->{app}->{config}->{appdir}/session"; $dir=~s|/+|/|g; my @MD = split /(?:\\|\/)+/, $dir; my $i; for ($i=$#MD; $i>=0; $i--) { last if -d join '/', @MD[0..$i] } for (my $j=$i+1; $j<=$#MD; $j++) { unless (mkdir join '/', @MD[0 .. $j]) {warn "Could not create the session directory \"$dir\" because $!\n"; exit 1} } $dir} );
 has rm              => (is=>'ro', lazy=>0, default=> sub{for (split /:/,$ENV{PATH}) {return "$_/rm" if -f "$_/rm" && -x "$_/rm" } warn "Could not found utility rm\n"; exit 1});
@@ -87,7 +87,7 @@ unless (-d $module_dir) {warn "Sorry could not find the Dancer2::Plugin::WebServ
 
 			if ((exists $method->{'Use sudo'}) && ($method->{'Use sudo'}=~/(?i)[y1t]/)) {
 			my $sudo = undef;
-			for (split /:/,$ENV{PATH}) { if ((-f "$_/sudo") && -x ("$_/sudo")) { $sudo="$_/sudo"; last } }
+			foreach ('/bin', '/usr/bin', '/usr/sbin', '/sbin') { if ((-f "$_/sudo") && -x ("$_/sudo")) { $sudo="$_/sudo"; last } }
 			unless (defined $sudo) {warn "Could not found sudo command\n"; exit 1}
 			$plg->auth_command( "$sudo \Q$method->{Command}\E" )
 			}
@@ -105,14 +105,13 @@ unless (-d $module_dir) {warn "Sorry could not find the Dancer2::Plugin::WebServ
 delete $plg->config->{'Authentication methods'};
 
 	# Check for an active auth method if there are protected routes
-	# Check if the Groups is an array
 	foreach (keys %{$plg->config->{Routes}}) {
 
-		if ( $plg->config->{Routes}->{$_}->{Protected} ) {
+		if ((exists $plg->config->{Routes}->{$_}->{Protected}) && ($plg->config->{Routes}->{$_}->{Protected}=~/(?i)[y1t]/)) {
+		$plg->config->{Routes}->{$_}->{Protected} = 1;
 
 			if ($plg->auth_method eq '') {
-			warn "While there is at least one protected route ( $_ ) there is not any active authorization method\n";
-			exit 1
+			warn "While there is at least one protected route ( $_ ) there is not any active authorization method\n"; exit 1
 			}
 			else {
 
@@ -124,6 +123,9 @@ delete $plg->config->{'Authentication methods'};
 				}
 			}
 		}
+		else {
+		$plg->config->{Routes}->{$_}->{Protected} = 0
+		}
 	}
 
 print "\nApplication             : $app->{name}\n";
@@ -143,7 +145,6 @@ print "Main PID                : $$\n";
 
 
 
-
 # Restore the valid sessions, and delete the expired
 opendir __SESSIONDIR, $plg->dir_session or die "Could not list session directory $plg->{dir_session} because $!\n";
 
@@ -178,7 +179,7 @@ opendir __SESSIONDIR, $plg->dir_session or die "Could not list session directory
 
 closedir __SESSIONDIR;
 #print 'debug : '. Dumper( $app )                   ;exit;
-#print 'debug : '. Dumper( $plg->config->{Routes} ) ;exit;
+print 'debug : '. Dumper( $plg->config->{Routes} ) ;exit;
 #print 'debug : '. Dumper( $plg->auth_config )      ;exit;
 #print 'debug : '. Dumper  \%TokenDB; exit;
 
@@ -235,7 +236,7 @@ closedir __SESSIONDIR;
 		if ($app->request->body) { 
 
 			eval  {
-			if    ($plg->Format->{from} eq 'json')	{ $plg->data(Cpanel::JSON::XS::decode_json   Encode::encode('UTF-8',$app->request->body)) }
+			if    ($plg->Format->{from} eq 'json')	{ $plg->data(Cpanel::JSON::XS::decode_json  Encode::encode('UTF-8',$app->request->body)) }
 			elsif ($plg->Format->{from} eq 'xml')	{ $plg->data(XML::Hash::XS::xml2hash $app->request->body) }
 			elsif ($plg->Format->{from} eq 'yaml')	{ $plg->data(YAML::Syck::Load        $app->request->body) }
 			elsif ($plg->Format->{from} eq 'perl')	{ $plg->data(eval                    $app->request->body) }
@@ -771,7 +772,7 @@ Dancer2::Plugin::WebService - RESTful Web Services with login, persistent data,
 
 =head1 VERSION
 
-version 4.3.1
+version 4.3.2
 
 =head1 SYNOPSIS
 
@@ -1195,7 +1196,7 @@ George Bouras <george.mpouras@yandex.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2019 by George Bouras.
+This software is copyright (c) 2020 by George Bouras.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
